==> scala-k8s-objects_sjs1_3-0.3.0-sources.jar: io/k8s/api/autoscaling/v2/ObjectMetricStatus.scala <==
package io.k8s.api.autoscaling.v2

import dev.hnaderi.k8s.utils._

/** ObjectMetricStatus indicates the current value of a metric describing a kubernetes object (for example, hits-per-second on an Ingress object). */
final case class ObjectMetricStatus(
  current : io.k8s.api.autoscaling.v2.MetricValueStatus,
  describedObject : io.k8s.api.autoscaling.v2.CrossVersionObjectReference,
  metric : io.k8s.api.autoscaling.v2.MetricIdentifier
) {

  /** Returns a new data with current set to new value */
  def withCurrent(value: io.k8s.api.autoscaling.v2.MetricValueStatus) : ObjectMetricStatus = copy(current = value)
  /** transforms current to result of function */
  def mapCurrent(f: io.k8s.api.autoscaling.v2.MetricValueStatus => io.k8s.api.autoscaling.v2.MetricValueStatus) : ObjectMetricStatus = copy(current = f(current))

  /** Returns a new data with describedObject set to new value */
  def withDescribedObject(value: io.k8s.api.autoscaling.v2.CrossVersionObjectReference) : ObjectMetricStatus = copy(describedObject = value)
  /** transforms describedObject to result of function */
  def mapDescribedObject(f: io.k8s.api.autoscaling.v2.CrossVersionObjectReference => io.k8s.api.autoscaling.v2.CrossVersionObjectReference) : ObjectMetricStatus = copy(describedObject = f(describedObject))

  /** Returns a new data with metric set to new value */
  def withMetric(value: io.k8s.api.autoscaling.v2.MetricIdentifier) : ObjectMetricStatus = copy(metric = value)
  /** transforms metric to result of function */
  def mapMetric(f: io.k8s.api.autoscaling.v2.MetricIdentifier => io.k8s.api.autoscaling.v2.MetricIdentifier) : ObjectMetricStatus = copy(metric = f(metric))
}

object ObjectMetricStatus {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.autoscaling.v2.ObjectMetricStatus, T] = new Encoder[io.k8s.api.autoscaling.v2.ObjectMetricStatus, T] {
        def apply(o: io.k8s.api.autoscaling.v2.ObjectMetricStatus) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("current", o.current)
            .write("describedObject", o.describedObject)
            .write("metric", o.metric)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, ObjectMetricStatus] = new Decoder[T, ObjectMetricStatus] {
      def apply(t: T): Either[String, ObjectMetricStatus] = for {
          obj <- ObjectReader(t)
          current <- obj.read[io.k8s.api.autoscaling.v2.MetricValueStatus]("current")
          describedObject <- obj.read[io.k8s.api.autoscaling.v2.CrossVersionObjectReference]("describedObject")
          metric <- obj.read[io.k8s.api.autoscaling.v2.MetricIdentifier]("metric")
      } yield ObjectMetricStatus (
          current = current,
          describedObject = describedObject,
          metric = metric
        )
    }
}

==> scala-k8s-objects_sjs1_3-0.5.2-sources.jar: io/k8s/api/autoscaling/v2/ObjectMetricStatus.scala <==
package io.k8s.api.autoscaling.v2

import dev.hnaderi.k8s.utils._

/** ObjectMetricStatus indicates the current value of a metric describing a kubernetes object (for example, hits-per-second on an Ingress object). */
final case class ObjectMetricStatus(
  current : io.k8s.api.autoscaling.v2.MetricValueStatus,
  describedObject : io.k8s.api.autoscaling.v2.CrossVersionObjectReference,
  metric : io.k8s.api.autoscaling.v2.MetricIdentifier
) {

  /** Returns a new data with current set to new value */
  def withCurrent(value: io.k8s.api.autoscaling.v2.MetricValueStatus) : ObjectMetricStatus = copy(current = value)
  /** transforms current to result of function */
  def mapCurrent(f: io.k8s.api.autoscaling.v2.MetricValueStatus => io.k8s.api.autoscaling.v2.MetricValueStatus) : ObjectMetricStatus = copy(current = f(current))

  /** Returns a new data with describedObject set to new value */
  def withDescribedObject(value: io.k8s.api.autoscaling.v2.CrossVersionObjectReference) : ObjectMetricStatus = copy(describedObject = value)
  /** transforms describedObject to result of function */
  def mapDescribedObject(f: io.k8s.api.autoscaling.v2.CrossVersionObjectReference => io.k8s.api.autoscaling.v2.CrossVersionObjectReference) : ObjectMetricStatus = copy(describedObject = f(describedObject))

  /** Returns a new data with metric set to new value */
  def withMetric(value: io.k8s.api.autoscaling.v2.MetricIdentifier) : ObjectMetricStatus = copy(metric = value)
  /** transforms metric to result of function */
  def mapMetric(f: io.k8s.api.autoscaling.v2.MetricIdentifier => io.k8s.api.autoscaling.v2.MetricIdentifier) : ObjectMetricStatus = copy(metric = f(metric))
}

object ObjectMetricStatus {

    implicit val encoder : Encoder[io.k8s.api.autoscaling.v2.ObjectMetricStatus] = new Encoder[io.k8s.api.autoscaling.v2.ObjectMetricStatus] {
        def apply[T : Builder](o: io.k8s.api.autoscaling.v2.ObjectMetricStatus) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("current", o.current)
            .write("describedObject", o.describedObject)
            .write("metric", o.metric)
            .build
        }
    }

    implicit val decoder: Decoder[ObjectMetricStatus] = new Decoder[ObjectMetricStatus] {
      def apply[T : Reader](t: T): Either[String, ObjectMetricStatus] = for {
          obj <- ObjectReader(t)
          current <- obj.read[io.k8s.api.autoscaling.v2.MetricValueStatus]("current")
          describedObject <- obj.read[io.k8s.api.autoscaling.v2.CrossVersionObjectReference]("describedObject")
          metric <- obj.read[io.k8s.api.autoscaling.v2.MetricIdentifier]("metric")
      } yield ObjectMetricStatus (
          current = current,
          describedObject = describedObject,
          metric = metric
        )
    }
}
